@@ -125,16 +125,22 @@ cgi-bin/cpanmail.cgi
 favicon.ico
 HERE
 
+[TOLINK]
+cgi-bin/response.html=response.html
+
 [TEST_RANGES]
 LIST=<<HERE
 199901-200412
 200301-200712
-200601-200912
+200601-201012
+200901-201312
 HERE
 
 [CPAN_RANGES]
 LIST=<<HERE
+199501-199812
 199901-200412
 200301-200712
-200601-200912
+200601-201012
+200901-201312
 HERE
